@@ -1,7 +1,7 @@
 package Locale::Codes;
 # Copyright (C) 2001      Canon Research Centre Europe (CRE).
 # Copyright (C) 2002-2009 Neil Bowers
-# Copyright (c) 2010-2023 Sullivan Beck
+# Copyright (c) 2010-2025 Sullivan Beck
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -16,7 +16,7 @@ use if $] >= 5.027007, 'deprecate';
 use Locale::Codes::Constants;
 
 our($VERSION);
-$VERSION='3.73';
+$VERSION='3.86';
 
 use Exporter qw(import);
 our(@EXPORT_OK,%EXPORT_TAGS);
@@ -316,7 +316,9 @@ sub code2names {
    my $type = $$self{'type'};
 
    my ($err,$code,$codeset) = $self->_code(@args);
-   return undef  if ($err  ||  ! $code);
+   return undef  if ($err  ||
+                     ! $code  ||
+                     ! exists $Data{$type}{'code2id'}{$codeset}{$code});
 
    my $id   = $Data{$type}{'code2id'}{$codeset}{$code}[0];
    my @name = @{ $Data{$type}{'id2names'}{$id} };
